@@ -1,47 +1,47 @@
 $VAR1 = {
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'uploads' => {
+                         'path' => '/var/www/htdocs/download',
+                         'maxlength' => 21000000,
+                         'chmod' => 438
+                       },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'scriptAlias' => 'perl',
           'language' => 'en',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'mod' => 'n',
           'database' => {
-                          'user' => 'root',
-                          'CurrentPass' => '',
                           'CurrentUser' => 'root',
-                          'CurrentHost' => 'localhost',
                           'name' => 'LZE',
-                          'host' => 'localhost',
                           'CurrentDb' => 'LZE',
+                          'host' => 'localhost',
+                          'user' => 'root',
+                          'CurrentHost' => 'localhost',
+                          'CurrentPass' => '',
                           'password' => ''
                         },
-          'version' => '0.8',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'admin' => {
                        'email' => 'your@email.org',
                        'password' => 'testpass'
                      },
-          'files' => {
-                       'chmod' => '0755',
-                       'group' => 'lze',
-                       'owner' => 'lze'
-                     },
-          'scriptAlias' => 'perl',
-          'uploads' => {
-                         'chmod' => 438,
-                         'path' => '/var/www/htdocs/download',
-                         'maxlength' => 21000000
-                       },
-          'apacheconfig' => undef,
-          'floodtime' => 10,
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'cgi' => {
-                     'expires' => '+1y',
-                     'serverName' => 'http://localhost',
-                     'cookiePath' => '/',
                      'DocumentRoot' => '/var/www/htdocs',
-                     'bin' => '/var/www/cgi-bin',
                      'title' => 'MySQL::Admin',
+                     'cookiePath' => '/',
+                     'style' => 'mysql',
+                     'serverName' => 'localhost',
                      'alias' => 'perl',
-                     'style' => 'mysql'
+                     'bin' => '/var/www/cgi-bin',
+                     'expires' => '+1y'
                    },
-          'mod' => undef,
-          'session' => '/var/www/cgi-bin/config/session.pl'
+          'files' => {
+                       'owner' => 'lze',
+                       'chmod' => '0755',
+                       'group' => 'lze'
+                     },
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'floodtime' => 10,
+          'version' => '0.81'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
