@@ -10,7 +10,8 @@ loadTranslate('config/translate.pl');
 my $content ="Lang =function (){\n";
 foreach my $lng (keys %{$m_hrLang}){
     foreach my $key (keys %{$m_hrLang->{$lng}}){
-      $content .= "this.$lng$key='$m_hrLang->{$lng}{$key}';\n"
+      my $out = lc  $key;
+      $content .= "this.$lng$out='$m_hrLang->{$lng}{$key}';\n"
     }
 }
 $content .= "}\n";
