@@ -6,7 +6,7 @@ my $cwd  = cwd();
 my $test = new HTML::Menu::Pages;
 use MySQL::Admin qw(:all);
 print header;
-print start_html(-title => 'HTML::Menu::Pages', -style => '/style/lze/pages.css',);
+print start_html(-title => 'HTML::Menu::Pages', -style => 'style/lze/pages.css',);
 my %needed = (
 
         length => '345',
