@@ -21,19 +21,19 @@ $m_sUser
 );
 $m_sDefaultClass = 'DBI::Library' unless defined $DBI::Library::m_sDefaultClass;
 @DBI::Library::EXPORT_OK
-    = qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver  useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB $m_dsn $m_dbh selectTable);
+    = qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver  useexecute quote quote_identifier void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB $m_dsn $m_dbh selectTable);
 %DBI::Library::EXPORT_TAGS = (
     'all' => [
-        qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB selectTable)
+        qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute quote quote_identifier void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists initDB selectTable)
     ],
     'dynamic' => [
-        qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
+        qw(quote quote_identifier CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
     'independent' => [
-        qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
+        qw(quote quote_identifier CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute selectTable)
     ],
 );
-$DBI::Library::VERSION = '0.79';
+$DBI::Library::VERSION = '0.81';
 $m_tbl                 = 'querys';
 $driver                = 'mysql';
 require Exporter;
@@ -538,6 +538,19 @@ sub quote {
     return $m_dbh->quote($sql);
 }
 
+=head2 quote_identifier()
+
+        $quotedString = $database->quote_identifier($sql);
+
+=cut
+
+sub quote_identifier {
+    my ( $self, @p ) = getSelf(@_);
+    my $sql = $p[0];
+    return $m_dbh->quote_identifier($sql);
+}
+
+
 =head2 selectTable
 
 set a placeholder wihich is usesd by dynmaic statements.
